@@ -9,7 +9,7 @@ const char *tqInstallPathDocs()         { return "/usr/local/share/doc/tqt3"; }
 const char *tqInstallPathHeaders()      { return "/usr/local/include/tqt3"; }
 const char *tqInstallPathLibs()         { return "/usr/local/lib"; }
 const char *tqInstallPathBins()         { return "/usr/local/bin"; }
-const char *tqInstallPathPlugins()      { return "/usr/local/plugins/tqt3"; }
+const char *tqInstallPathPlugins()      { return "/usr/local/lib/tqt3/plugins"; }
 const char *tqInstallPathData()         { return "/usr/local/share/tqt3"; }
 const char *tqInstallPathTranslations() { return "/usr/local/translations/tqt3"; }
 const char *tqInstallPathSysconf()      { return "/usr/local/etc"; }
